==> OneSignal-3.15.3-sources.jar: com/onesignal/OneSignalAPIClient.java <==
package com.onesignal;

/**
 * Modified MIT License
 * <p>
 * Copyright 2019 OneSignal
 * <p>
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * <p>
 * 1. The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * <p>
 * 2. All copies of substantial portions of the Software may only be used in connection
 * with services provided by OneSignal.
 * <p>
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import android.support.annotation.NonNull;

import org.json.JSONObject;

public interface OneSignalAPIClient {

    void put(final String url, final JSONObject jsonBody, final OneSignalApiResponseHandler responseHandler);

    void post(final String url, final JSONObject jsonBody, final OneSignalApiResponseHandler responseHandler);

    void get(final String url, final OneSignalApiResponseHandler responseHandler, @NonNull final String cacheKey);

    void getSync(final String url, final OneSignalApiResponseHandler responseHandler, @NonNull String cacheKey);

    void putSync(String url, JSONObject jsonBody, OneSignalApiResponseHandler responseHandler);

    void postSync(String url, JSONObject jsonBody, OneSignalApiResponseHandler responseHandler);
}

==> OneSignal-4.4.0-sources.jar: com/onesignal/OneSignalAPIClient.java <==
package com.onesignal;

/**
 * Modified MIT License
 * <p>
 * Copyright 2019 OneSignal
 * <p>
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * <p>
 * 1. The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * <p>
 * 2. All copies of substantial portions of the Software may only be used in connection
 * with services provided by OneSignal.
 * <p>
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import androidx.annotation.NonNull;

import org.json.JSONObject;

public interface OneSignalAPIClient {

    void put(final String url, final JSONObject jsonBody, final OneSignalApiResponseHandler responseHandler);

    void post(final String url, final JSONObject jsonBody, final OneSignalApiResponseHandler responseHandler);

    void get(final String url, final OneSignalApiResponseHandler responseHandler, @NonNull final String cacheKey);

    void getSync(final String url, final OneSignalApiResponseHandler responseHandler, @NonNull String cacheKey);

    void putSync(String url, JSONObject jsonBody, OneSignalApiResponseHandler responseHandler);

    void postSync(String url, JSONObject jsonBody, OneSignalApiResponseHandler responseHandler);
}
